==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescription } from "./SelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectedItemsChangedEventArgsDescriptionMetadata, _super);
    function SelectedItemsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
            SelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemsChangedEventArgsDescriptionMetadata.c(SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(SelectedItemsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldItems", "Collection:object:ObjectCollection:Object");
        a.item("NewItems", "Collection:object:ObjectCollection:Object");
        a.item("CurrentItems", "Collection:object:ObjectCollection:Object");
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("SelectedItemsChangedEventArgs", function () { return new SelectedItemsChangedEventArgsDescription(); });
        a.z("SelectedItemsChangedEventArgs", SelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemsChangedEventArgsDescriptionMetadata, 'SelectedItemsChangedEventArgsDescriptionMetadata');
    SelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemsChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescription } from "./SelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectedItemsChangedEventArgsDescriptionMetadata, _super);
    function SelectedItemsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
            SelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemsChangedEventArgsDescriptionMetadata.c(SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectedItemsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldItems", "Collection:object:ObjectCollection:Object");
        a.item("NewItems", "Collection:object:ObjectCollection:Object");
        a.item("CurrentItems", "Collection:object:ObjectCollection:Object");
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemsChangedEventArgsDescriptionMetadata.b(a);
        a.ac("SelectedItemsChangedEventArgs", function () { return new SelectedItemsChangedEventArgsDescription(); });
        a.ab("SelectedItemsChangedEventArgs", SelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangedEventArgsDescriptionMetadata.$t = markType(SelectedItemsChangedEventArgsDescriptionMetadata, 'SelectedItemsChangedEventArgsDescriptionMetadata');
    SelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemsChangedEventArgsDescriptionMetadata };
